@@ -1,22 +1,29 @@
 from typing import List
 
 from spacy import util
-from spacy.tokens import Doc
+from spacy.tokens import Doc, Span
 
 from .classy_skeleton import classySkeleton
 
 
 class classySpacyInternal(classySkeleton):
-    def __init__(self, nlp, name, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        Doc.set_extension("cats", default=None, force=True)
+    def __init__(self, nlp, name, data, config, include_doc, include_sent):
+        super().__init__(data=data, config=config)
+        self.include_doc = include_doc
+        self.include_sent = include_sent
+        if include_sent:
+            Span.set_extension("cats", default=None, force=True)
+            if "sentencizer" not in nlp.pipe_names:
+                nlp.add_pipe("sentencizer")
+        if include_doc:
+            Doc.set_extension("cats", default=None, force=True)
         self.name = name
         self.nlp = nlp
         self.set_training_data()
         self.set_svc()
 
     def get_embeddings(self, text: List[str]) -> List[float]:
-        """ Retrieve embeddings from text.
+        """Retrieve embeddings from text.
         Overwrites function from the classySkeleton that is used to get embeddings for training data.
 
         Args:
@@ -27,9 +34,9 @@ class classySpacyInternal(classySkeleton):
         """
         docs = self.nlp.pipe(text)
         embeddings = [self.get_embeddings_from_doc(doc) for doc in docs]
-        
+
         return embeddings
-    
+
     def get_embeddings_from_doc(self, doc: Doc) -> List[float]:
         """Retrieve a vector from a spacy doc and internal embeddings.
 
@@ -59,9 +66,12 @@ class classySpacyInternal(classySkeleton):
         Returns:
             Doc: spacy doc with ._.cats key-class proba-value dict
         """
-        embeddings = self.get_embeddings_from_doc(doc)
-        embeddings = embeddings.reshape(1, -1)
-        doc._.cats = self.get_prediction(embeddings)[0]
+        if self.include_doc:
+            embeddings = self.get_embeddings_from_doc(doc)
+            embeddings = embeddings.reshape(1, -1)
+            doc._.cats = self.get_prediction(embeddings)[0]
+        if self.include_sent:
+            doc = self.set_pred_results_for_doc(doc)
 
         return doc
 
@@ -76,11 +86,21 @@ class classySpacyInternal(classySkeleton):
             Doc: spacy doc with ._.cats key-class proba-value dict
         """
         for docs in util.minibatch(stream, size=batch_size):
-            embeddings = [self.get_embeddings_from_doc(doc) for doc in docs]
-            pred_results = self.get_prediction(embeddings)
-            
+            pred_results = [self.get_embeddings_from_doc(doc) for doc in docs]
+            if self.include_doc:
+                pred_results = self.get_prediction(pred_results)
+
             for doc, pred_result in zip(docs, pred_results):
-                doc._.cats = pred_result
-                
+                if self.include_doc:
+                    doc._.cats = pred_result
+                if self.include_sent:
+                    doc = self.set_pred_results_for_doc(doc)
+
                 yield doc
-  
\ No newline at end of file
+
+    def set_pred_results_for_doc(self, doc: Doc):
+        embeddings = [sent.as_doc().vector for sent in list(doc.sents)]
+        pred_results = self.get_prediction(embeddings)
+        for sent, pred in zip(doc.sents, pred_results):
+            sent._.cats = pred
+        return doc
